@@ -2,6 +2,8 @@
 
 #include "decoder.h"
 
+#include "../exceptions.h"
+
 #include <utility>
 
 ChunkReference& ChunkReference::operator+=(const ChunkReference& other) {
@@ -18,12 +20,12 @@ uint32_t ChunkReference::getOffset() const {
     return fileReference & 0xFFFFFFFF;
 }
 
-size_t makeFileReference(size_t fileId, size_t offset) {
+size_t makeFileReference(uint64_t fileId, uint64_t offset) {
     return ((fileId - 1) << 32) | offset;
 }
 
 std::pair<size_t, ChunkReference> readHeadChunkMeta(Decoder& dec,
-                                                    size_t fileId) {
+                                                    uint64_t fileId) {
     ChunkReference ref;
     ref.type = ChunkType::Head;
 
@@ -36,8 +38,9 @@ std::pair<size_t, ChunkReference> readHeadChunkMeta(Decoder& dec,
 
     auto encoding = dec.read_int<uint8_t>();
     if (encoding != 1) {
-        throw std::runtime_error("Head chunk meta has unknown encoding: " +
-                                 std::to_string(encoding));
+        throw pdu::unknown_encoding_error(
+                "Head chunk meta has unknown encoding: " +
+                std::to_string(encoding));
     }
 
     size_t dataLen = dec.read_varuint();
