@@ -30,8 +30,10 @@ public:
 
     std::shared_ptr<ChunkFileCache> getCache() const override;
 
-private:
-    void loadChunkFile(Decoder& dec, size_t fileId);
+protected:
+    // allow tests to default construct and manually load data
+    HeadChunks() = default;
+    void loadChunkFile(Decoder& dec, uint64_t fileId);
 
     std::shared_ptr<ChunkFileCache> cache;
 
